# ip_calculator
[![CI](https://github.com/jmillana/pycidr/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/jmillana/pycidr/actions/workflows/ci.yml)

A cli utility to get detailed IP information
         
         IP Address Information for: 172.14.15.16/21    
|||
|---------------------|-------------------------------------|
| Class               | B                                   |
| CIDR block          | /21                                 |
| IP Address          | 172.14.15.16                        |
| Network Mask        | 255.255.248.0                       |
| Network ID          | 172.14.8.0                          |
| Broadcast Address   | 172.14.15.255                       |
| Total Addresses     | 2048                                |
| Usable hosts        | 2046                                |
| Binary IP           | 10101100.00001110.00001111.00010000 |
| Binary Network Mask | 11111111.11111111.11111000.00000000 |
